@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2000 Ed Cashin
+Copyright (C) 2001 Ed Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -37,7 +37,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	<sys/types.h>
 #include	<dirent.h>
 #include	<errno.h>
-#include	"hashtbl/xstrdup.h"
+#include	"xstrdup.h"
 #include	"xstradd.h"
 #include	"elcwft.h"
 #include	"elcwft_p.h"
